@@ -31,7 +31,7 @@ Archive::SevenZip - Read/write 7z , zip , ISO9960 and other archives
 
 =cut
 
-our $VERSION= '0.11';
+our $VERSION= '0.12';
 
 # Archive::Zip API
 # Error codes
@@ -190,7 +190,10 @@ sub version {
         local $/ = "\n";
         my @output = <$fh>;
         if( @output >= 3) {
-            $output[1] =~ /^7-Zip\s+.*?(\d+\.\d+)\s+(?:\s*:\s*)?Copyright/
+            # 7-Zip 19.00 (x64) : Copyright (c) 1999-2018 Igor Pavlov : 2019-02-21
+            # 7-Zip [64] 16.02 : Copyright (c) 1999-2016 Igor Pavlov : 2016-05-21
+            # 7-Zip [64] 9.20  Copyright (c) 1999-2010 Igor Pavlov  2010-11-18
+            $output[1] =~ /^7-Zip\s+.*?\b(\d+\.\d+)\s+(?:\(x64\))?(?:\s*:\s*)?Copyright/
                 or return undef;
             return $1;
         } else {
@@ -203,7 +206,7 @@ sub version {
 
   my @entries = $ar->open;
   for my $entry (@entries) {
-      print $entry->name, "\n";
+      print $entry->fileName, "\n";
   };
 
 Lists the entries in the archive. A fresh archive which does not
@@ -374,7 +377,11 @@ sub extractMember {
         warn $_ if $options{ verbose };
     };
     if( basename $memberOrName ne $target_name ) {
-        rename "$target_dir/" . basename($memberOrName) => $extractedName
+        my $org = basename($memberOrName);
+        if( $^O !~ /mswin/i) {
+            $org = encode('UTF-8', $org);
+        };
+        rename "$target_dir/" . $org => $extractedName
             or croak "Couldn't move '$memberOrName' to '$extractedName': $!";
     };
 
